==> ulyxex.0.0.7.with-tinyMce.zip: pages/code/admin_page_add.php <==
<?php
class PageAdd extends Admin {
	function __construct() {
		$this->h = New Html();
		$this->tr = New Translate();
		$this->tree = New Tree();
	}
	public function add_page_form() {
		$content = $this->h->input("hidden","add",1);
		$content .= $this->h->p( $this->tr->w("sub page of").$this->tree->pathsSelect() );
		$content .= $this->h->p($this->tr->w("hide").$this->h->input("checkbox","hide","on"));
		$content .= $this->h->p($this->tr->w("title")).$this->h->p($this->h->input("text","name","","size=".FIELDWIDTH));
		$content .= $this->h->p($this->tr->w("description")).$this->h->p($this->h->textarea("","description",array(8,FIELDWIDTH)));
		$content .= $this->h->p($this->h->input("submit","save",$this->tr->w("save")));
		$result = $this->h->form($content,"page","post","admin.php?action=add_page");
		return $result;
	}
	public function add_page() {
		$hide = (isset($_POST['hide']))?1:0;
		$query1 = "INSERT INTO ".PAGES."  (NAME,PARENTID,DESCRIPTION,HIDE,USERID) VALUES (".
											"'".$this->h->safe($_POST['name'])."',".
											"'".$this->h->num($_POST['parent'])."',".
											"'". $this->h->safe($_POST['description'])."',".
											$hide.",".$_SESSION['userid'].");";
											// print $query1;
		$link = mysqli_connect(HOSTMYSQL, USERMYSQL, PASSMYSQL, BASEMYSQL);
		mysqli_query($link, $query1);
		// mysqli => get the id of the page for reuse
		$pageId = mysqli_insert_id($link);
		$query2 = "INSERT INTO ".USERPAGES."  (USERID,PAGEID) VALUES (".$_SESSION['userid'].",".$pageId.");";
		mysqli_query($link, $query2);
		mysqli_close($link);
		$result = $this->h->h3($this->tr->ws("page").strip_tags($_POST['name']).$this->tr->wsp("created !"));
		return $result;
	}
}
?>

==> ulyxex.0.1.0.with-tinyMce.zip: pages/code/admin_page_add.php <==
<?php
class PageAdd extends Admin {
	function __construct() {
		$this->h = New Html();
		$this->tr = New Translate();
		$this->tree = New Tree();
	}
	public function add_page_form() {
		$content = $this->h->input("hidden","add",1);
		$content .= $this->h->p( $this->tr->w("sub page of").$this->tree->pathsSelect() );
		$content .= $this->h->p($this->tr->w("hide").$this->h->input("checkbox","hide","on"));
		$elements = array($this->tr->w("date")=>0,$this->tr->w("subject")=>1,$this->tr->w("reverse date")=>2);
		$content .= $this->h->p($this->tr->w("sort type").$this->h->select($elements,"sortstyle"));
		$content .= $this->h->p($this->tr->w("title")).$this->h->p($this->h->input("text","name","","size=".FIELDWIDTH));
		$content .= $this->h->p($this->tr->w("description")).$this->h->p($this->h->textarea("","description",array(8,FIELDWIDTH)));
		$content .= $this->h->p($this->h->input("submit","save",$this->tr->w("save")));
		$result = $this->h->form($content,"page","post","admin.php?action=add_page");
		return $result;
	}
	public function add_page() {
		$hide = (isset($_POST['hide']))?1:0;
		$query = "INSERT INTO ".PAGES."  (NAME,PARENTID,DESCRIPTION,SORTSTYLE,HIDE,USERID) VALUES (".
											"'".$this->h->safe($_POST['name'])."',".
											"'".$this->h->num($_POST['parent'])."',".
											"'". $this->h->safe($_POST['description'])."',".
											"'". $this->h->num($_POST['sortstyle'])."',".
											$hide.",".$_SESSION['userid'].");";
		$this->q($query);
		$result = $this->h->h3($this->tr->ws("page").strip_tags($_POST['name']).$this->tr->wsp("created !"));
		return $result;
	}
}
?>
